# Hivecode
Hivecode is a series of libraries desgined to make programming less of an artisan task 
and more of an engineering task. It includes functions, decorators and multiple classes
desgiined to make the implementation of development and analytical proyects more oriented
to desigin and architecture and less of an implementation hell.

## Features

- Decorators developed by hand in order to improve performance.
- Usefull patterns, easy to implement in your code.
- Some random fun tools that might be handy at any point.

## Installation

Hivecode requires [Python](https://www.python.org/downloads/) 3.8.0+ to run.

> Note: It is highly recommended to specify the version you want to import.

### Pypi

You can also check out our [Pypi]() website.

```sh
pip install hivecode.native
```

## Documentation
You can check out the documentation at our [Read the Docs]().

## Development

### Requirements
Build is used to build the packages that will be deployed into pypi.
```sh
pip install build
```
Twine is used to deploy packages to pypi.
```sh
pip install twine
```
Sphinx is used to build the documentation.
```sh
pip install Sphinx
```